@@ -34,8 +34,14 @@ include_once('./functions.php');
 
 set_default_action();
 
-if (get_request_var('action') == 'testdb') {
-	test_database_connection();
+// database test
+if (get_nfilter_request_var('action') == 'testdb') {
+	if (get_nfilter_request_var('location') == 'local') {
+		install_test_local_database_connection();
+	} else {
+		install_test_remote_database_connection();
+	}
+
 	exit;
 }
 
@@ -228,16 +234,23 @@ if ($step == '7') {
 			$description  = "Local Linux Machine";
 		}
 
-		$host_template_id = db_fetch_cell_prepared('SELECT id FROM host_template WHERE hash = ?', array($hash));
+		$host_template_id = db_fetch_cell_prepared('SELECT id
+			FROM host_template
+			WHERE hash = ?',
+			array($hash));
 
 		// Add the host
 		if (!empty($host_template_id)) {
 			cacti_log('Device Template for First Cacti Device is ' . $host_template_id);
 
-			$results = shell_exec(read_config_option('path_php_binary') . ' -q ' . $config['base_path'] . "/cli/add_device.php" .
-				" --description=" . cacti_escapeshellarg($description) . " --ip=" . cacti_escapeshellarg($ip) . " --template=$host_template_id" .
-				" --notes=" . cacti_escapeshellarg('Initial Cacti Device') . " --poller=1 --site=0 --avail=" . cacti_escapeshellarg($avail) .
-				" --version=$version --community=" . cacti_escapeshellarg($community));
+			$results = shell_exec(read_config_option('path_php_binary') . ' -q ' . $config['base_path'] . '/cli/add_device.php' .
+				' --description=' . cacti_escapeshellarg($description) .
+				' --ip=' . cacti_escapeshellarg($ip) .
+				' --template=' . $host_template_id .
+				' --notes=' . cacti_escapeshellarg('Initial Cacti Device') .
+				' --poller=1 --site=0 --avail=' . cacti_escapeshellarg($avail) .
+				' --version=' . $version .
+				' --community=' . cacti_escapeshellarg($community));
 
 			$host_id = db_fetch_cell_prepared('SELECT id
 				FROM host
@@ -251,11 +264,19 @@ if ($step == '7') {
 					WHERE host_id = ?',
 					array($host_id));
 
+				cacti_log('Creating Graphs for Default Device');
 				if (sizeof($templates)) {
 					foreach($templates as $template) {
 						automation_execute_graph_template($host_id, $template['graph_template_id']);
 					}
 				}
+
+				cacti_log('Adding Device to Default Tree');
+				shell_exec(read_config_option('path_php_binary') . ' -q ' . $config['base_path'] . '/cli/add_tree.php' .
+					' --type=node' .
+					' --node-type=host' .
+					' --tree-id=1' .
+					' --host-id=' . $host_id);
 			}
 		} else {
 			cacti_log('WARNING: Device Template for your Operating System Not Found.  You will need to import Device Templates or Cacti Packages to monitor your Cacti server.');
@@ -379,44 +400,7 @@ $enabled = '1';
 <!DOCTYPE html>
 <html>
 <head>
-	<title>Cacti Server Installation/Upgrade</title>
-	<meta http-equiv='Content-Type' content='text/html;charset=utf-8'>
-	<meta http-equiv='cache-control" content='no-cache' />
-	<meta http-equiv='expires" content='0' />
-	<meta http-equiv='pragma" content='no-cache' />
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/main.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/jquery.zoom.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/jquery-ui.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/default/style.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/jquery.multiselect.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/jquery.timepicker.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/jquery.colorpicker.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/modern/pace.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>include/fa/css/font-awesome.css' type='text/css' rel='stylesheet'>
-	<link href='<?php echo $config['url_path']; ?>images/favicon.ico' rel='shortcut icon'>
-	<link rel='icon' type='image/gif' href='<?php echo $config['url_path']; ?>images/cacti_logo.gif' sizes='96x96'>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery-migrate.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery-ui.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.cookie.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/js.storage.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jstree.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.hotkeys.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.tablednd.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.zoom.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.multiselect.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.multiselect.filter.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.timepicker.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.colorpicker.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.tablesorter.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.metadata.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/jquery.sparkline.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/Chart.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/dygraph-combined.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/js/pace.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/realtime.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/layout.js'></script>
-	<script type='text/javascript' src='<?php echo $config['url_path']; ?>include/themes/modern/main.js'></script>
+	<?php print html_common_header(__('Cacti Server Installation/Upgrade'), 'modern');?>
 	<style type='text/css'>
 	input, select {
 		font-size: 12px;
@@ -468,7 +452,7 @@ $enabled = '1';
 						print '<h3>' . __('Location checks') . '</h3>';
 
 						// Get request URI and break into parts
-						$test_request_uri = $_SERVER['REQUEST_URI']; 
+						$test_request_uri = $_SERVER['REQUEST_URI'];
 						$test_request_parts = parse_url($test_request_uri);
 						$test_request_path = $test_request_parts['path'];
 						$test_request_len = strlen($test_request_parts['path']);
@@ -494,23 +478,6 @@ $enabled = '1';
 						$test_config_path = $config['url_path'] . 'install/';
 						$test_compare_result = strcmp($test_config_path,$test_final_path);
 
-						/*
-						 * Uncmment the following to debug the above change
-						 *
-						print '<p>Testing [' . $test_config_path . '] matches [' . $test_final_path .'] result = '.$test_compare_result.'('.gettype($test_compare_result).')</p>';
-
-						print '<p>request_uri = ' . strlen($test_request_uri) . ' [' . $test_request_uri . ']</p>';
-						print '<p>request_parts = ' . var_export($test_request_parts, true) . '</p>';
-						print '<p>request_path = ' . strlen($test_request_path) . ' [' . $test_request_path . ']</p>';
-
-						print '<p>script_name = ' . strlen($test_script_name) . ' [' . $test_script_name . ']</p>';
-							print '<p>script_part = ' . strlen($test_script_part) . ' [' . $test_script_part . ']</p>';
-						print '<p>script_result = ' . $test_script_result . '</p>';
-						print '<p>final_path = ' . strlen($test_final_path) . ' [' . $test_final_path . ']</p>';
-						 *
-						 * The above code should probably be removed once tested.
-						 */
-
 						// The path was not what we expected so print an error
 						if ($test_compare_result !== 0) {
 							print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Please update config.php with the correct relative URI location of Cacti (url_path).') . '</p>';
@@ -519,6 +486,7 @@ $enabled = '1';
 						}
 
 						print '<h3>' . __('MySQL TimeZone Support') .'</h3>';
+
 						$mysql_timezone_access = db_fetch_assoc('SHOW COLUMNS FROM mysql.time_zone_name', false);
 						if (sizeof($mysql_timezone_access)) {
 							$timezone_populated = db_fetch_cell('SELECT COUNT(*) FROM mysql.time_zone_name');
@@ -535,7 +503,16 @@ $enabled = '1';
 							print '<p>' . __('Your Cacti database account has access to the MySQL TimeZone database and that database is populated with global TimeZone information.') . '</p>';
 						}
 
-						print '<h3>' . __('PHP Timezone Support') .'</h3>';
+						print '<h3>' . __('MySQL Temporary Table Access') . '</h3>';
+
+						if (!install_test_temporary_table()) {
+							print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Your Database user account does not have permission to create temporary tables.  Please add this permissiong before continuing.') . '</p>';
+							$enabled = '0';
+						} else {
+							print '<p>' . __('Your Database user account can create temporary tables.') . '</p>';
+						}
+
+						print '<h3>' . __('PHP Timezone Support') . '</h3>';
 
 						if (ini_get('date.timezone') == '') {
 							print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Your Web Servers PHP Timezone settings have not been set.  Please edit php.ini and uncomment the \'date.timezone\' setting and set it to the Web Servers Timezone per the PHP installation instructions prior to installing Cacti.') . '</p>';
@@ -544,7 +521,7 @@ $enabled = '1';
 							print '<p>' . __('Your Web Servers PHP is properly setup with a Timezone.') . '</p>';
 						}
 
-						print '<h3>' . __('Required PHP Module Support') .'</h3>';
+						print '<h3>' . __('Required PHP Module Support') . '</h3>';
 
 						print '<p>' .  __('Cacti requires several PHP Modules to be installed to work properly. If any of these are not installed, you will be unable to continue the installation until corrected. In addition, for optimal system performance Cacti should be run with certain MySQL system variables set.  Please follow the MySQL recommendations at your discretion.  Always seek the MySQL documentation if you have any questions.') . '</p>';
 
@@ -555,59 +532,37 @@ $enabled = '1';
 
 						form_alternate_row('phpline',true);
 						form_selectable_cell(__('PHP Version'), '');
-						form_selectable_cell('5.2.0+', '');
-						form_selectable_cell((version_compare(PHP_VERSION, '5.2.0', '<') ? "<font color=red>" . PHP_VERSION . "</font>" : "<font color=green>" . PHP_VERSION . "</font>"), '');
+						form_selectable_cell('5.4.0+', '');
+						form_selectable_cell((version_compare(PHP_VERSION, CACTI_PHP_VERSION_MINIMUM, '<') ? "<font color='red'>" . PHP_VERSION . "</font>" : "<font color='green'>" . PHP_VERSION . "</font>"), '');
 						form_end_row();
 
+						// Common PHP extensions needed for installation
+						$extensions = array(
+							array('name' => 'session',   'installed' => false),
+							array('name' => 'sockets',   'installed' => false),
+							array('name' => 'PDO',       'installed' => false),
+							array('name' => 'pdo_mysql', 'installed' => false),
+							array('name' => 'xml',       'installed' => false),
+							array('name' => 'ldap',      'installed' => false),
+							array('name' => 'mbstring',  'installed' => false),
+							array('name' => 'pcre',      'installed' => false),
+							array('name' => 'json',      'installed' => false),
+							array('name' => 'openssl',   'installed' => false),
+							array('name' => 'gd',        'installed' => false),
+							array('name' => 'zlib',      'installed' => false)
+						);
+
+						// OS specific PHP extensions needed for installation
 						if ($config['cacti_server_os'] == 'unix') {
-							$extensions = array(
-								array('name' => 'posix',     'installed' => false),
-								array('name' => 'session',   'installed' => false),
-								array('name' => 'sockets',   'installed' => false),
-								array('name' => 'PDO',       'installed' => false),
-								array('name' => 'pdo_mysql', 'installed' => false),
-								array('name' => 'xml',       'installed' => false),
-								array('name' => 'ldap',      'installed' => false),
-								array('name' => 'mbstring',  'installed' => false),
-								array('name' => 'pcre',      'installed' => false),
-								array('name' => 'json',      'installed' => false),
-								array('name' => 'openssl',   'installed' => false),
-								array('name' => 'gd',        'installed' => false),
-								array('name' => 'zlib',      'installed' => false)
-							);
-						} elseif (version_compare(PHP_VERSION, '5.4.5') < 0) {
-							$extensions = array(
-								array('name' => 'session',   'installed' => false),
-								array('name' => 'sockets',   'installed' => false),
-								array('name' => 'PDO',       'installed' => false),
-								array('name' => 'pdo_mysql', 'installed' => false),
-								array('name' => 'xml',       'installed' => false),
-								array('name' => 'ldap',      'installed' => false),
-								array('name' => 'mbstring',  'installed' => false),
-								array('name' => 'pcre',      'installed' => false),
-								array('name' => 'json',      'installed' => false),
-								array('name' => 'openssl',   'installed' => false),
-								array('name' => 'gd',        'installed' => false),
-								array('name' => 'zlib',      'installed' => false)
-							);
-						} else {
-							$extensions = array(
-								array('name' => 'com_dotnet','installed' => false),
-								array('name' => 'session',   'installed' => false),
-								array('name' => 'sockets',   'installed' => false),
-								array('name' => 'PDO',       'installed' => false),
-								array('name' => 'pdo_mysql', 'installed' => false),
-								array('name' => 'xml',       'installed' => false),
-								array('name' => 'ldap',      'installed' => false),
-								array('name' => 'mbstring',  'installed' => false),
-								array('name' => 'pcre',      'installed' => false),
-								array('name' => 'json',      'installed' => false),
-								array('name' => 'openssl',   'installed' => false),
-								array('name' => 'gd',        'installed' => false),
-								array('name' => 'zlib',      'installed' => false)
-							);
+							$extensions[] = array('name' => 'posix',     'installed' => false);
+						} elseif ($config['cacti_server_os'] == 'win32') {
+							// Microsoft COM and DotNet no longer in core PHP as of 5.4.5
+							if (version_compare(PHP_VERSION, '5.4.5') >= 0) {
+								$extensions[] = array('name' => 'com_dotnet','installed' => false);
+							}
 						}
 
+						// Verify and display extension test results
 						$ext = verify_php_extensions($extensions);
 						foreach ($ext as $id =>$e) {
 							form_alternate_row('line' . $id);
@@ -615,7 +570,9 @@ $enabled = '1';
 							form_selectable_cell('<font color=green>' . __('Yes') . '</font>', '');
 							form_selectable_cell(($e['installed'] ? '<font color=green>' . __('Yes') . '</font>' : '<font color=red>' . __('No') . '</font>'), '');
 							form_end_row();
-							if (!$e['installed']) $enabled = '0';
+							if (! $e['installed']) {
+								$enabled = '0';
+							}
 						}
 
 						html_end_box(false);
@@ -623,6 +580,7 @@ $enabled = '1';
 						print '<h3>' . __('Optional PHP Module Support') .'</h3>';
 
 						print '<p>' . __('The following PHP extensions are recommended, and should be installed before continuing your Cacti install.') . '</p>';
+
 						$extensions = array(
 							array('name' => 'snmp', 'installed' => false),
 							array('name' => 'gmp', 'installed' => false)
@@ -659,7 +617,7 @@ $enabled = '1';
 							if (cacti_version_compare($old_cacti_version, CACTI_VERSION, '<=')) {
 								// upgrade detected
 								print '<h4>' . __('Upgrade from <strong>%s</strong> to <strong>%s</strong>', $old_cacti_version, CACTI_VERSION) . '</h4>';
-								print '<p> <font color="#FF0000">' . __('WARNING - If you are upgrading from a previous version please close all Cacti browser sessions and clear cache before continuing.  Additionally, after this script is complete, you will also have to refresh your page to load updated JavaScript so that the Cacti pages render properly.  In Firefox and IE, you simply press F5, in Chrome, you may have to clear your browser cache for the Cacti web site.') . '</font></p>';
+								print '<p> <font color="#FF0000">' . __('WARNING - If you are upgrading from a previous version please close all Cacti browser sessions and clear cache before continuing.  Additionally, after this script is complete, you will also have to refresh your page to load updated JavaScript so that the Cacti pages render properly.  In Firefox and IE, you simply press F5.  In Chrome, you may have to clear your browser cache for the Cacti web site.') . '</font></p>';
 							} else {
 								// downgrade detected
 								print '<h4>' . __('Downgrade from <strong>%s</strong> to <strong>%s</strong>', $old_cacti_version, CACTI_VERSION) . '</h4>';
@@ -794,7 +752,7 @@ $enabled = '1';
 							strURL = 'index.php?action=testdb';
 							$.post(strURL, $('input').serializeObject()).done(function(data) {
 								$('#results').html('<b><?php print __('Remote Database: ');?></b>'+data);
-								if (data == 'Connection Successful') {
+								if (data == '<?php print __('Remote Connection Successful');?>') {
 									test_good=true;
 									$('#next').button('enable');
 								}
